darkhistory.electrons.ics.ics_cooling — DarkHistory documentation

# darkhistory.electrons.ics.ics_cooling

Electron cooling through ICS.

Functions

`get_ics_cooling_tf`(raw_thomson_tf, …[, fast]) | Transfer function for complete electron cooling through ICS.
`get_ics_cooling_tf_fast`(raw_thomson_tf, …) | Transfer function for complete electron cooling through ICS.

#### Previous topic

darkhistory.electrons.ics.engloss_diff_terms.engloss_diff_expansion

#### Next topic

darkhistory.electrons.ics.ics_cooling.get_ics_cooling_tf

### This Page

Show Source